Parser

Struct Parser 

pub struct Parser<'src> { /* private fields */ }
A parser for Haskell 2026 source code.

Implementations

Source

impl<'src> Parser<'src>

pub fn parse_module(&mut self) -> ParseResult<Module>

Parse a complete module.

pub fn parse_import(&mut self) -> ParseResult<ImportDecl>

Parse an import declaration.

pub fn parse_local_decls(&mut self) -> ParseResult<Vec<Decl>>

Parse local declarations (in let or where).

Source

impl<'src> Parser<'src>

pub fn parse_expr(&mut self) -> ParseResult<Expr>

Parse an expression, including optional type annotation.

Source

impl<'src> Parser<'src>

pub fn is_pattern_start(&self) -> bool

Check if the current token can start a pattern.

pub fn parse_pattern(&mut self) -> ParseResult<Pat>

Parse a pattern.

pub fn is_apat_start(&self) -> bool

Check if current token can start an atomic pattern.

pub fn parse_atom_pattern(&mut self) -> ParseResult<Pat>

Parse an atomic pattern. This is used for function argument patterns in clause LHS.

Source

impl<'src> Parser<'src>

pub fn parse_type(&mut self) -> ParseResult<Type>

Parse a type.

pub fn is_atype_start(&self) -> bool

Check if current token can start an atomic type.

pub fn parse_atype(&mut self) -> ParseResult<Type>

Parse an atomic type.

Source

impl<'src> Parser<'src>

pub fn new(src: &'src str, file_id: FileId) -> Self

Create a new parser for the given source code.

pub fn has_errors(&self) -> bool

Check if there are errors.

pub fn take_diagnostics(&mut self) -> Vec<Diagnostic>

Take the diagnostics.